(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    167923,       2985]
NotebookOptionsPosition[    166558,       2936]
NotebookOutlinePosition[    167060,       2955]
CellTagsIndexPosition[    167017,       2952]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Batch processing with Mathematica", "Title",
 CellChangeTimes->{{3.474817283304102*^9, 3.474817288374489*^9}}],

Cell[CellGroupData[{

Cell["Introduction", "Section",
 CellChangeTimes->{{3.474817643104488*^9, 3.474817644822618*^9}}],

Cell[TextData[{
 "Suppose you want to run some calculations in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as a batch and have them scheduled to run at a certain time. How do you do \
that?\n\nThis notebook explains how Macintosh users can set up scheduling of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " calculations. In this example you will download data into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", and process the data. After the data is processed ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will send you (or someone else) an email. The examples shows how this can \
be scheduled daily for 8:15am."
}], "Text",
 CellChangeTimes->{{3.474817571159112*^9, 3.474817607118167*^9}, {
  3.474817761725359*^9, 3.474817805410178*^9}, {3.4748178682952213`*^9, 
  3.474817942350471*^9}, {3.475845729654661*^9, 3.475845754733996*^9}, {
  3.475849053187948*^9, 3.475849175670836*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Section",
 CellChangeTimes->{{3.474818007872469*^9, 3.474818012142912*^9}}],

Cell[TextData[{
 "When the code below is evaluated it downloads CBOE Volatility Index\
\[RegisteredTrademark] (a.k.a VIX\[RegisteredTrademark]) data, which is a key \
measure of market expectations of near-term volatility, from the Chicago \
Board Options Exchange website and saves it to a directory. A plot of the \
date is generated and emailed to someone (normally you!). To make this code \
functional you will have to replace the input that is ",
 StyleBox["colored red",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " with your own file path and email details. The cell containing the code is \
an ",
 ButtonBox["initialization cell",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/InitializationCell"],
 ". After making the changes to the code below, save the notebook and you \
will be greeted with this prompt:"
}], "Text",
 CellChangeTimes->{{3.4758459041787453`*^9, 3.475845935489278*^9}, {
   3.475846161862233*^9, 3.475846224681058*^9}, 3.47584628272434*^9, {
   3.47584636097513*^9, 3.475846533209893*^9}, {3.475846574202786*^9, 
   3.475846608954458*^9}, {3.475846685532751*^9, 3.4758466924512253`*^9}, {
   3.475846740861183*^9, 3.475846743244334*^9}, {3.4758483441818533`*^9, 
   3.475848381765698*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvfl7E1e676v73D/g/nLOc85z9t7du7t3D4kykYkAImEIkwgEEhQICYhA
EhQIISIERJjEEBQGEUBMIgliiAgIiBgswAJkoAALEIPAMggQpmzKdtmSzZDs
vufsfvreNVSValgqyRM2ZH1bnceUqla9a6hX71q11mf9Yezkt8b+3waDoQ78
//r/ZTDAv5kV3Yzjdt29e/dm+bVKKioqKqqHqJqaGuB+KyoqOI4rL1m3bdu2
8vLyeDx+kYqKiorqIQo4XuB+q6urb926lannL126dJ6KioqKqp0EnHA6nY5H
mXNUVFRUVO2q69evx2Kxs1RUVFRU7SrgiqNUVFRUVB1Ap6moqKioOoBOUlFR
UVF1AB2noqKiouoAKqGioqKi6gA6SkVFRUXVARSmoqKiouoAOkRFRUVF1QF0
gIqKioqqA2g/FRUVFVUH0B4qKioqqg6gIBUVFRVVB9BuKioqKqoOoJ1UVFRU
VB1AO6ioqKioOoC2U1FRUVF1AA2loqKiouoAylBRUVFRUVFRUVFRUVFRUVFR
UVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFR
UVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVE91koD1de3txVUVFRUv3XVXy6/
ffFye1tBRUVF9VtXrX93eVG4va2gomof8WwyHovF44kUy7W3LTriAi671eaK
tpmNPJdKxGFJJFIduRwec9XMcF3Zsae9rcBiPWaDQkaT3R1I8u1tF9VDV8xn
Qy3AEmbb7iZs0GWVNzdXpE1uxjEeZas2u/xMExs16zaBK81tVBos45YbaLK6
49QlP3Sla2rrho2/9WOgvQ3BEryx2e7yej0uh80ktA5b24UE7aeYw2w0Wr3E
nMX9TpPRYPVEH7ZRHcWSuF30DFZvIbfmAw4LcHPeaBOcnOiCzJ5gKBwMuB12
X7RNnJ1wI6PF7fU4rELA4WaadC/8aJjb5uciw0X9DqcnFI5Egl5sn6WgYqci
q/L8hUxlVVOvSl+8ku72Rs33W9vCpKZL8MZuRnRRLIMjJJMLjqXwqajbbjHi
I2abP5JUJ5AK28xAtnBKOBDx2EB8jRo+G/I6zUYhOHF6hSiDi/osJpPF7oe3
5GNOi9lktjNKF8nFA/AcRwAdZn128C9rMAEf/GTYbTLawDPCJ0J2i5S81ROK
42ujPofJZHZ4Az6nBQX7Fh+TAnd1mMTo32jyKh9MLuYzCl8aTSbBmETEbzPj
a4xWhyeaIrodNuxzmk3C1TZfVLDW4giG/VZw2OIBd+KTEZfNLCTl9OOiItpP
tCQe8lrxLYxmdzCmNSIR8lhMUkrOiNC3ESwJMUG7yQhktrpjOX5kU2EXLhqU
iD0ulUyOyop6bWLYaTTbfag0ydUtlxh+q3/rSfYj481mZ1C0BbQ0k9HhjxVS
III3Nntw+3GZcByeytVmiPWIvTHKBhdwWo1GSwC1wBylDRptyI4bjNnmcoH7
mOw+wcHqGpxy4EIPxDNUzdX1s+cTSz3pmpqmXbZt96+vDa75dk3bGNVUCd4Y
NFTpUMRlxu44xTEWHMrYPQGvE7c/V1jlkJO4qVtwLMdG4MVWH5fh/Dbc/Gy+
gM+K/7QHeOlJMblT0vna/iAfRR1aSwQ8TqmgUYjZQDPmffALRwKlAx1BIBQU
bBPCGMYtDr4YzcJTY3KzfNLvQgYZLU6XO6TsFvLJMDYWPkduH/gyGXLiJJy+
gMeOE7QyalfGBezCL5XT4/U4bXYvA3u40uAP8PtWL8tGcDE6vH436nyYXJFM
Dvu1liSCDuzFQTHirotX41IjbqvFAeLNkNeB686D3aOiJHAefATfBc70WpAT
5mLYXTrFH9dclQU8Ek7QZHW4fRE+d3UryjkRMIplIx8QI9of99twDeAGx7ih
icAfFlIgojeGZifCHnxTEBvnaDPkesTemOHBTw9sc1YPo1faYi2b7G6/xyHU
P6pofYNjfvSt2ZUgVQxV4Sqavej2wuWFn5+urU2P//LvPYdUTvkqnU4XelV9
/e2z59pmUhzBG+NmDx7ACHJ80C0Lx82CZ1MmkQjgPq4DPDVRj0VobMKTawrg
Rhb3G8UHWXrA0XOA27C2P8gH0NPtirDJgNiHtvg4PmoRG7mQgWQiEY84ZEN8
gv0WdxI6dZkz4dGPixAvqYUtN7vxE4fHDMWfmEwK/+LYA8onRsij0afwBkKR
2n3Cw4ufZfC4xVguGfFk7clhP9kSd5jjU9hpmN2RDEEcSCkWQp5HSF+wxAZ9
i1As8qLLlnXcL2UW3x10m3GWclcWp+hV5a5uldhYwCp5ZIM5EJPO0NgvBgPo
FnEbbgCFFYhqVBYmKfSzSGWuV48Wrw/2GkCMrvxlUVsruFzlw2KGpa1ncNwP
27bR5m3DofrfjC7Gzu98sWd67Q+FXnDkRGOfEY093q5+a1T97dsFXnR69brr
Bw4108Q8InjjsBNHQJ4Qdr9Wn9DvlYdJcolPjSsYsIkPMhfzYgca4eTnwAdZ
HrfIj6uURM3b7PC6gTOz2O045vbBg17U0U1GvOIot/BoR2TeGHszgjMxq39N
sISrBGfFYp8kjjSmXDjEdipmwnAxH86jMmYWYyrxYCQbK4tC8V4e+5WWKByL
2qPyIbdVeQbOozjyyWmTVSjkFAZkTCaxr24w+uN8JqNTWYqWo1PdJHHRoFvM
OyiKXPZnQshjghg7HnGJ9yqkQKRxY6vH5/P6ApG40GaJZa5bj4JsPmlQl2yt
EAMY7DiSF35SkTfObXASB80h9RNF1UxtnepIduqW3rg575npWr5h8rwHfUZl
eoyo6zms7ujxvJfU19Udmbfg2MTP0nVtNMtBPW7Mxfy4udr8cSFMEh+NGI7x
NLFxRnxqsAQPxobRIZPQ0lIhPKCWjY2NTjigGvPLBxkUSoWlp8ERTESlNm3E
o5pCyOGGIye4S05wOwRvLPZ8VcLjM6qIVOzXC3Ggza/s5gt5FByXskizORJi
Y6NDFVjnsp9oCdGLYvFxHy4W+EKMQ2GeOF4qtySnNxZ+pGxut9vlcoH/2tDA
qskZyhYgobKEYRAxNs5Z3TnNFsJX08HTuewXsya2gkRhBZI1W90PylHmevVo
8QVcQsNGvzu5SlsYEjfh1pXEvlkeG5MMZiOhYCAYplOYWkvnT57c0umlhs6m
+sXL6qv0XuqlQyV3+4xteP2D9Ouj7/V4r869QT/luurqIzO+2vTsC9yZs61q
slyCNzZaHeBJdNhEj4e6+cAfCp7ZHWDCXuG3n/SugY+JT0028mSFC8zOcDTs
wm8CLbBHxkXx7COTzSG9xicGUVJwYgqxGV64SvASUiO3uX0+cdKUzRvhdbyx
0CE12D3+SEwdjiTFwT1vIBRL8bgLCZLxhiJBDx5MNYfVF4l5BL38QCgU8Drd
QU77Ll68r8nqhGf5PDarM8rltF9lidAFBt+6fKFQ0Od2OHyKl++iy7J4AwGn
YI8VjQAU5I2xG3HL4kJO8JMw0M1dWRzOu9nuDoZjfO7qlivqtZltTl8gFA4H
HPgckyuZ0/6MfOhbmumRt0DU9S47nKPM9eqR4aW41xxM5i5t8e2GwWSWQhOz
fNxYazAH34qaLQ7N+wiqZqq+vv7bd9691OmlX0yvNUz4NHPmHPG09NWbje/P
udt3YkO/CeneH9W/ZuVHfJ7OPSWjqqzs0Me2n554JjpvfpvZniHMNzZZXL5I
doQtFrRmw16j059rEg7ucylGPDJ8wmvPpm62exNCDAAiB/HltQsPi1iIXVoh
3jCjtyR8FPtEaZ5SPOAUbba7HPjBMIJgDD87FhRbCs5E+I3gguLzY3RqVt+w
jBTgO1EuGJ8zO8BpsgXjJBOVeUSmCjGVPEdcImQ3ZxMD+QYPYC77tZbEAi55
/1p6nSQq5RNnJlocLmwOyqDCEsaDi0XljVPQQZlU/YWkUxgnj+tUVjLikcxM
6VV3VkI3QWpPFgeakJDLfnQXwZUpZkHnKxBQhPJ6zypnmeepx5Tgj03ORG5r
U4xf+IWxe/B8HmkIhWxwnvEcquZo99Jl64xPp1/p+kuP3o0Dhjas96WvK6Mo
9k7jF2vv93c0vPFVpt+0utftNT0/qe1q5X8q0qZWx3GXN20J9ui9y/jMbtNr
XPnVh5SN3GJTUFzu/hSP39qIrzAUX7HwalZzMQvV4h4aBxIXUmFJdyGYKrtE
K2yr/GyU9TxPi5jHPCEOh8pRYWRu+9WWZHh0cc4sZlPiuWRSr7KaodyVxaly
lKu6sydwbDKZAEoqF6A13f48BZJTucu8wHrMYS0XCYZi4G8OHGLwHA3la9/m
GkzVFF06cnTaE0+WPP/yg1f73u018Jfe7zSO+Lxx7faG0/H01VTm5OXGaZvv
DXI1DHdn3l6aHvpNbf+51X0c1d0/495y1F+9KaVTz3G3DhxgRo3d+8zze+Cn
08npM9oxXwUrgYNIR4g4IktF9VtQymlQyuSMU8f70FV148bSV7ote+LZ6i79
7va23Ov3wb0+nzzo9+XdoYsaR3saRq7NvLsuPXZjepyvfuxG/v31NcNW3TF/
UzVgAdtz2u2xi7g9kTvh49dXfhd776NI5x7h51858HznomdfDHV6+cbBA+2d
uQLExQM+n89P3wxT/aaVikX8Xo/LCeTyBZu28I+qVVRfV1dx+fKPw99f+Ken
Dnfq9aDXyMZ+E+8OmdP4jrtx1PrMuM11E7fXTtlV80WQmxq88/nOqgnbq8Zu
YYetv/W258YQd/nrs+LdJ8W6WEtfGnzihd6Rl3ocebFb5KXukRe6nhg4hC94
FhwVFRXVb1zpdDq2zb/m+VeW/c645q9duNdGNQ6ckRm+PPOhr27Sjuov99yZ
c5Cdd+j2wiO35ocr5hZXOIpuTdh1c8y2q6M2Xxn53cWh38YGzC/t8dmpru8x
r5gjL/ViXu5xskvPMy+/dvkLR3tnjoqKiupRUs1t1tf/jaW/+8vSP3Q+2mnI
3cEL0taNNZ/tqpoZuvX14RtLS26sYJIrT15dfuLaN8eS8w5ftRdd/mTPuQ93
Rj/afmrkD8zg5Sf6zCruPGbXs31Odukf7dL/bLd+lzr3Tn2Xfw4zFRUVFZVc
JV8tXP+nv67641O+v/TmByxIf7irclro2vzDZe4TZZ7SK+vPlm04m1gbLV95
6uqCyBXHoejnocj4veHxe0LvbT/89uZ9PWZ+8qcXtz/X93zX4Re6WeLdh13p
PIALFbd3tqioqKg6iuqqq2uqq/OedvA9+5a/dN70t6c2PfFU9OVhtaN/ujH7
WOzrE2eXn4qtO3fRdz6++cKVjbGy1acSX0cuzw0fm15cNPHgjo8O/WQ96O27
5L3/+MvEPzxxrsuHsdcmxnuMT/Qcd63biNqS0w8hg1RUVFSPhOpupsrWbyxb
uupS8eGq6zdV36bT6eqy8phr3c6n3/Y//eaOp17abnxu+9Odil7sd+K9RSVz
jx5bfaHUd+nCj5cvb7tUtuXiFU/0+pKScueRwzOP77Qf877748wuo8f82/8Y
9i//z8ZOI8/2W3zW/HW83+xrr395s/v42iOl7ZJlKioqqo6pNFtZvcp7s8/g
G30HXf14UvLLmddnz7v21dzy6XMujP2MeX3kwWct+7t+tLvbx3s69Qw990rR
s132PNNl91NddnU2B8csYFYdvrIncW3/teTOxPUfYhVLj5XPPhj4xOfuO8nx
pyc//Zf/Nv5f/832738sMq86btlSavnu0rBVVwd9k+o1vWb5T+2ddSoqKqoO
p7ro2crR46s697r5co8bL/e89nLvyy/3OfvCgNNdRx7vOelIvxn7B8w90O3d
khe7H36hx8FOfUPPDQo+O3CHsffWToOClqmR6RtOzPnx6Gdr9g2bvuFly9f/
/vLM//Hnr/7lr7N/97T9X//41VM9d76/p2js3hPjAuetW8tHrL81eGnVwLm8
L5Rmmwy0p6Kionq8VV9ZVTH1q8pXeqVe6nXzlQHXOg9KvDryUq9PzppnnXxz
ydG31hb3m366S++TL/ePvDjs0PPvHnx5zN4utm2dx3//4ofrXhy36rlRy4yW
xX8e/PXv+s37Xa/5f+j9zZ/7fPMfr87+X3+e333CpklHA58dDE/aH52wu2zc
tpsjN1QNWcr1dNSMdNYu3VJ36ET9xSv1t25DQnJ9fRqolk9XsOnLZfXHTqbP
X0rX1bV38VBRUVE9PPFVVZV2R62pf9WrgytfG3H79fHXB85IDHNfHPXdqVE/
RYYsufDaoLNd3jnRZfzhbpMP9vhy/wBnYMg3PwxdvHrQwmX95rhem7ao62df
v/DRNy+P+bbL6BWdRix7wjz398+sHLJw29Rju6YfPeQIn/qy6MpnwZsf/si+
u+7O4G9qXp+W7jGRf21s/YAP64dNSH8wNfOJo37CzLr3P+GHjKr9cHLdD/70
1WTh7HoqKiqqx0P1N1P82E/rXn27uu9Y7o2pVe8sqfh4Y3LyrkuTi86O/T7x
+nuXXh1/qufsowPdobdX7hq+YduYrb7xW9d8uGnJe2sXDl0+z7zw636zV745
Z/2gaet62dzPDZv1L89sGr9h/7zT+6cfOTItXPrlwbh933Vb4Pb7G++89W31
ACff78v63p9keo9t6D26sfd793uPaOg5rHbc5Nrtu+vZylbPIJ+MeLzh9oL8
JSN+X6iZG4S1r+WSFRGfN9SUDYBbkmWqZihZ4vcVdfQCl4xsFWt5NuZ12q1W
e/Cx25q67sx5fsDYur622qHOmnEbKr/clZpbnJh/7MrUXTcGTCjr/VX0jVVH
3/sxZPvZ//HPmz4r2jj94IavDrgn75w3xjdnxNqv3129etzK70Z/4x08bfHz
I2b+d+OumbvCK2JHFzEnZx+9MD1cZi+6btt127qletgafsCi+n4zMn0nN/Qb
n3n9g8Y+71VbPqoN7EnX1rY8I5pNKQwGo+tyxCkwEgsVYg9aPNLC/IjT7NSw
gAsUvLlDg7ss0I4mW94WYlEOmmBFS7L8KIkrftJgKGpG+MCV9Ick1RxXkpOt
XGQwzCgm10KJE34HTyppfoOREmkjSek3+0aVEPLcvwR536ANEvJ9Xk8w9hjy
M9Jrfmzo93ndSHftJH+V8+DNpcevuKNlc/dVDJxZPujb6Pv+8Pj9P087vHlS
aM3EgxudJVuWHls//+DXk7fN+2jrN5/4107d8v2ktWtHznM+8+6c/97pyLxg
fM25siUnyhaWlM89fG3GwRuf72XHb6+2bqwbtjI9eH6j+cvGvrb7fT+osc+r
u1zWWrnAiEc2HjQZjIF4Cv2TYxmXweBqyi+ouP+auAMm8Ma53RHcR8PkVgNp
JUVcJqNTb1sHPTuQ5e3d2liXUeASF6ioW5vlPKXUMYV2BDDnZqdXlpaUknfe
1hdX0s1gWFSSq0ilZBWFlihl4jluVrKo25POEnRpgmEKB60p0q9ENyg4D02W
ZGTW2iYKeeNuxfB3inPDNvm4RcWS0onrDe8trB+9umZakHUdvfbtqYtrzpbP
2FX15uKr7205OXF/0bTDgXnHdy47vf7Lw+5PD/m/Pfaj5+jymTuWTNmxeu4e
r/PnlZ9uXDjYOafTmIX/67UzC4PshvMV355KLT5+bdGxq3PC16cfuD11b834
7en31jUOWXTXPP1u3wmZ5T/U32mDIuUiJoNJonlDn2Z0BnyY8m32Cz+mnLgd
mNGj3jY6u0lHEH2T9cYyiLfNE0Ib1ki8cbgFM5cICfsLWz3C1sDAGzu8HrwB
sRnTyEEyYbtA6zZJu64nwiLt3GQLJbiM3BunIuA2zpCMLpsMmQ3mgABAZ71W
kyOY0JqHtvMwCUB7jrEarSoSeDwgIuiN1hBOjY06BR47JpNjbwz/inis4l7A
2tITjxhNJs3ObqpSImY/W/pRAXIuYPllUH2T1Q1sDLvMZpcQe7MRtxHvpBxy
CztxezRhuaxY8H6aBAO4qM1k8we9+DynPyZu843TZPh4QKTUm9y4IrjSz7tB
zD7hWmSatJeGW8U/y3pjUHFmVyCA92o2OwKsLFlloXE+m2U1Cqe1VSb5Ny62
ob91QyW0yAvOMRrhzoAmkxHR4NXFqKqUmM9mXc0QGznZTmWWwl5hQxBca9oH
geCN1S0tj7A3LqnMMB7RclkH9jFTg+P79LjvquccrFh24sqKaMxz5tbH3jvD
15XZgsemH9m74MRud3S/N3Z4a3zLN8yK6UXbVh9ZvWD32oV7fSsPuqfvmvX+
+tmDFjq7TXb9adAZ18+VP8ar1p9NrjpdtpQpcx2/vqikYtaB6kmB9OjvG4cu
udd/esP3P7dVTtTeGO8p5oolE7ABok50Am5Aaoc77sBdFSxRRTwB/Y87wsDt
DdBuC6I35uFFJmeM5UH4DRqm1R/P8HGHEe47mYT4crgRMNpsLgX8uRlttYN3
7nD4IslkFO5AYfGB0+wwmSALLg7BTcrg/mWJAHyQg9CiENxIzhYXfkc8HB+3
ZTdsyhrpNgl7NKDNdEB+SebJI1tlsWAlmBCTAIeSILM4TMIlAyziUkkEIIcp
uKIs2oDeFEK/JtrSSwTtcGefBMulGJBN9T6bylIiZF92KkzbFoBbaCRxLMgx
oTD8dUIbabkYloVbfOKQlfPi6C7hR+lweN95j2KvZJSgwRaKg25SMpEEmSUZ
IGwvZQnGkgxsJbC/H4f7dBj90STL8RwqKZBcGJSUEe9LCJwqCtVI12KT4M+l
WI6y9pn1xnhjJlcwlmC8wrYdUrKKQqtc9KTBicJpbZVJ/q2yZBFIGLpsHu4j
DbqJDNqdBP2Oq4tRmT5I5EmUCLkVEeyUtyJUxJ5wnOPYRDxJfBC03ljT0vJI
8sbgV8cB0ffRvPsmPKJK83UNU79P2zZXOw/fdJ+8tDp2+avd1cOXVlq3XLYf
jMw/XrQ8evD7i8cC5aX7r50tvrln05nV8/euWrBr86oDqxfuXvD5ptnjvp87
bMX8Xl8t/Isl8sV6dvfVxI+Xrvxw4ZInesVTWr70xK15h2sm706P/qFxwMIG
d6ANM6ONjQ12HFYywrgB54eN1GQHQj/hytaFPBh42tEDZQvEgEeF3piPwSdN
HLKIgIfB7IXbjYnOB28xZrLa7HhHaOT20R3FXXhg88P7pkntmQUhncUbjfut
2RE/aL/BG+PQ74jZAp5+e1DbWtGePhbQ4sPAudiCuczT98ZwD8Cw3+1y2cRc
gLDKgDYVCjBJwULwlRU4OaMYimtLDz7CUjZJIxWqUlJnX34q3t7I4vAwSdGp
8qmw3+tCGyehvbESKMepDBvEOxTjLa6syCCDapSbj9ng9qzZCJxsACpzP455
xS4J2lDPJHWIU7Gw1+1ywJLCW06LbpN0LShHKypHT0Az1CH3xkbQwBKK2pGS
lRVaRuaNtVWW9caM6I3xfdD2jlZplz11McrTFxPJ0YoIdsryA9uDuBV7JseD
oPXGmpaWR1lvjOxxPr4bPqUPRxusK+rtgWrn0WvLz15ecJB711k7zH37wx3x
6cVHFzGhb88Ubzh/ckfZyZ1lkZ+uHAlc3ru5dNOqQ96le9ct2uOesWvRxB1f
W79zDV7oenaMf8Cka0XXE9vLLn1//vz3sUurz5a7mVtzD9fYgw0jvY0TvOnK
thzzIYxUCKOv4iguB0MY0GuNMpFIhGGirCY2FvaSg5uvmaxmowt646gFNmMh
XRg6o+3G3JIfQ43fFYzARCORaIIV7ugSh/6QNy6Hu8NLzzi83OxhYnBfSXGI
GD3dnige8bbYzChW0bpj1JW2e+CwCnDducyDkS0+yIWN6ucIhi6g5xmKRv12
o0l0oSAO9KBN1uw4LgIp2aC7cwSELac1pcf5LKAQhGwSvbGslAjZV+UswQib
fuKo1QJt9DKxiF3cWS8KQy63H3QirH5eGAmxBBhc8CBylBUWKiWbP+uNyQag
NoPLSRogQn+YZNvwmb0hJuK3C81J4Y3V1+JyDHgcMBv2gKL2ZN5YGgUiemM3
wRsTqozsjZNB2LcTh3RIxShPX/LGOVuR2k5ZfmDxW/2yEiY8CMRxY2VLyyO5
N27qu4xHSPWXyzMfL2n8YHX9F7u5BSdvOIuq351WN3hGzTurK8bvuvzV4aNf
M0XLSsPrz53+qSx+4PqVyM0T+y6fLbm+Z9PpNQv3fr/40I51xzctjWyYsWfd
mDUrekxZ9R/mk+5gYkf5mU0XohtiFz1nypcyt2eHayfvarR4GjYdadv8qLxx
JPuASO/UkGM04+FZnlVtWyav6yTejhHFErzfAjfXhV+wjA3+GYNN0QI3bUIn
wy6w2RXCG4zhbeAY0MczOqKwz52CHtcGOgUw/LB4oQtiUXgAfCkOJ7wMcjXI
t0R5ZLnRzWWScKDQ6NC+nom4zHggEw9qk8yDeQHehufiLtXWz7CgGDgmAmOe
BDQT700Zj8bxjvbCSAgeqeBSISdyyHFi6TFwc1Abk+LYGOzeqkcqFKVEyL7s
TD4ejaZE20CQhqrPEEjioXIxbEOuBvaOoyg/qBfjwsO5vGqrNtT1NtqBbeAr
NFJBMkDWZiSPykO/bQzCwRkYjKG648OwpFya2FhzrViOsAEYlBssqr2xsueS
9cbyQhO9ManKCCMVLAMjcytsDDzHcbgtqYtRnr6USM5WpDfehYrYB0NcPplI
8qQHQeuNNS0NTn5b5PZrd4PFkr3Fe2y9cV28rG6CMzNiduajNZkpQX7a9vr3
P20c8kn9m/NqRqy//cnuK7MOn1jEHFoWLVkXO+O/EttdfmzH5RsXqy8ev3Vw
y/l9m8+sm3vIbQ99v+Do5ln7/RN+2DJ0/rqnh2/v/3HpxvPHf7h4wnMm9u3p
a67jlTMP1E3Y0fDWtw1bHq43lsXGTHaGAxcSNz3X7HKL+0FiXSfgVubC5tGy
7Y9Ndl9K+N4pvYng4kEpUeyRkDcW91cGbhm/FIn6pC137T4xpPQ5pEt9TEph
OR+DMZbZre7RJaFt2b0jSebFfMJW9TYXcOpmVVQjvJgxGG02GKK4GRbvxYxz
FIT+Fj4suDTiAWihG76205Re9tYmi3bcWFlKxOxLhZ/d9dvigj9AfBzv+Az6
tDYYMJtRWIviMZNLKpB40CVelg3txFzGXGKa2DCCAVzELPeoQoNJ4AvNbgbn
HRpls6GqYNBENcEba68VdvfG9gQTSnukGW7ZspV7YyFZRaFVurvh2JhUZW5Z
bPzkokohApEJxLekYpRXipQIqRWR7FRmSXpFCGIDmAnCgyCkn/1D3dLAV/3h
HLYcU/+EGW7ZkYrHzRvXlhy/8/HntRZb/fuO9Jhl9eO+aRw1tnH42MzQqfVD
v+FHbKi0/XxtZrj0a6Z4SWnxt2dOb71cVnS95kpd/c3Gg5svnN5z9dDmS4f8
8WWfFc8btef7Sbt3fLRhx5vzt3X7+Pv/eHXXhJXhtZeOu09dWMzcnBep/nJ/
ZvzWxreW3v1ifZrvEAufea45Oz0TLuJQ/CGmCr+X/RO/itLs7Myz2v12kUGF
24MeOtUrSIJ5MNXcO/vCL3Fq0mWFmaEpPRAm626OrCmlXCejlBUBM/i3+Efu
MS58Wc5NqNUxs87JyguFs3ixpNTRd26DCryF7u3lhSaZpKmygkQqRlL6GWIj
z5s6qdby5L+JDf5xVf0djvVuvDHQUjVwePVbH9QM+6TeMr5xxHv3RljvvjOx
cei0zJsL6y1rqz/amXIcvuBiTqyMnvj+0qV9yYqTVTWX6y4fvHnQez6659qR
rZcPbb7sX3LaM+HA+uGbd763cmf/GTs6f+A39tv41KtF03YzrtNXnBF2xoHa
T3dlxngbLd/cHzAlvb85Ew6plOI8puy7Myqqh6l6Ue1tyCOvauZU2bgJV0x9
r7zWv7zXwJt9h/D93r436K37Q9++P2z4/SGjG9+wNQ6c3jBkWf1oP/tlcZmL
Oes5c+q7C2f9Vy7vv548WnH8hwuRjZciWy+Hfri4e825LQtPbvsyvMO69eeh
S3b3/GLXC+9uf6rvd3987seXhyY/L75tP1xr21M/dlNmhLtxyOx7fW1335+S
Tt5o72J45MXRuIKqPQScMM/zNTU1tbW1dXV11Cc3Q2mumjtyLDFp+ukXuzOd
Oh947qXw86/EuvSs6jGgoYf5Xt8BD8DHPOiB+e0Hb4y+P/DTe286G4dvqLPt
T80pubT01JmVZ0q950u3XD7tv1K08sx+z7ngqnM7V5wJLD0d+OroHtvefSO+
39Nn/s8v2XY+89Z2Y4+Nf3nB87vfF7/4zr1hP9x9Z0PD28saBs1qHPDp3b7W
B72HNU6ZmamidE0qqkdM2BWzLPvPf/5z3759VVVV4J/UIReodDrNp26xP+0u
+WDi9526r3m284buPTZ0Ne3qajrc2XS0U+eSTq+cfP7VMy/2PdN54MXuI6/1
G5968/Pat6fctXz1y4il98f+mP7i0K15JZcXM+dWRE+tOXd07bmfFzG7F54A
n+DXzL45JQcmHQi/92O4/5JDr0wKPffOnqd773zq5S1PPPfdn/+28g//uvvJ
7pGX30++OobvNfZe7/fu9Xrr7msDf+05IDNnXrqmpr2Lp+OJT/g9vhbSUIjo
nlbHy/DJktUbiptnaT64UJNpRW2hRw361ORCa4aRwPFyHFdWVvZPJOCQKysr
tQ65JW3jMVbdnTvJ0KHzPwUu7T9wrbS0oqwM9HCrb9+uunYtdTaaKApdCew6
s3RVyQeTD3WzHHnZerz/9NPDvz330dYLn+1MfrKxbtSqBx9ty0w9VDk7Uv71
iQtLT51ecvLIrKPgE5kdOf7VkROTQ6dGbzs9aPnJrpNPdHoz/EL3A51e2v3s
01uf+Ou6P/67+/f/Ouf3/3PBn7qu/2u/rU/1Dnfqff2VPg1de98z9bzfrWd6
9rw2WRz9SIsNG9QLUposIrqn1ckwLcHU5IMLkWhFBYF6Hg3oU0uKTueehELT
v6DpZCrgdUE8fO7cOeCKn3jiiX/84x9Eh9w2GXzkVSArGJxWdf7ShVnfnu7z
aWz44kvjN16c8vO5WYfPzyyuGr/5/riNDZ/uqZ5anJp59Nqso2VTi8u+OFRm
P3DZFoyP3BTv/83F1yafe2PyKcusyFDnnkGLfuo7f+Nr07/rOmHtc5Zlf3rR
+cc/L/p9pzV/emXJH59d/Oent/zt6SNPPce+0PleZ1Pd51PrkwUtxnk0xEfN
cN6R+icmH4JGJryaoGW/UURaUWHAliYQflSLv5okwiIRRdHhOaWqUigE1POI
QJ90CT9NaC2KLBALrQVGkgRcLvC9paWlwBuDcs7lkFvSNqiw6vm6K1PdF4bO
LvtoXdlnP5ZN23NlZvGFGYe4sevvj1rXOHYbP2539cd7qj7cVTX2J/b9LbeG
rrvRc+bVwTOvLNl/8btzZ5dHS6eFj4zes39Y4OeB3wfe8GzrNXvLSx/6/mpe
/4eXVv/bM6v/8MzyJ59d+MTTs//2lPMvf9v85FPx5zvfGDC4/ue96RYPPbnM
Rrw8IYMW2JocQRICJRP1WC1i681CdZD4RMCEICpAIafFZPOjP+MOkyWYVHNX
SDQVTmKxGK1eWboKBA1cF+cRpgGbbB51zxJ5Y69fwODYvRH8zOqAcbQkGSKt
SOaNc0KTVDAZYgFKkj1xhBwRkER6cCFV0cE5pQ5/wEki6sBK9AuJYxCQTI8C
9ElG+MkLLCImnqO+SIWm23KIRmrOZ31Ws9MH7wR+m6pOr+s7dNGqrz/E3lhy
yFOGdYL/ePLjQ1drMtQbt5IqftwbHzyl7IOlVz/57qrdf/WL3Ze/2B//bGfD
yEV331nSMGRF/Vvra4eurBns5gYsrOo++dpbMy6tOXnRd/nimrPnl568MPtw
bOJeZsSW8IBVB/ot3Nvjyx3Pjwp0HXlijvvS9mD5oSM3omeunTpddvzE+YMH
I9t+2rNg0e7hIyOvvl42dQZ/qUWjmhG4Igx3jvBy+yQJgSIPeLSLeiDwxBkW
VmyBHi/DZ3g47dyR1HJXSDQVLh4wYqSJcmasHEGD1i6ZgnEWLpEzGfDy3qw4
RKExOSKJZDTgBH/6YpwuGIdAkiHRitTAFjI0SQGTITJkspKeOGKOCEgiXbiQ
sugEp0om6qBqQsZwyaQqsnskoE/ydXN5gEXExHPUF6nQdFsOwUjC+bidG72R
GKiaiuNL4T1etUveWHLIe/btCy/ra+i/tgrEz9Qbt4Zu7yqKD/iw/L2Z1z5Y
cs3mLf9sS9nnO85P2Xd7zLL7Q+13zVMyfWbU93bwvafUmj68OWBC6TdHo57z
Mc/Z+MrSxGKmfFa4/NOf46M2nR3yLdNr9mHTxFD3MTcjp3TuCHo3ty5euvzj
tisrV9+Jnmm+6ckgaBjeOGi1EPKUICNQFN5Yu6gnZIdDb2zUDSIk0Brd0VTE
YRR6ghruCon6EjFrl4MpEDS835qdJ4w4M5ao/BGBSUlYmwSmCuiBcZBlKpKM
llaUynrjPNCkLEwmRwFKEp+4XDlSWZUPLqQoOn2iDg6kjQ4PWris0KMBfco6
q3zAImLi5PoiFZp+y9EaSTofJmsPCn2oiuNfGwyf7hNHKlQOeWTf/2YwfJXk
+dvHF1Jv3HKltm6/3GdE2ZBPykc4ykctSny4+sqE7y9M2Hpp3Jp7b39412xt
eP3DdK/x9a+N4nqNODN1d+niM+eXnL7sPl2++MSN+Ucrvjp4a+KOGyPXJ974
+vzrX57sPPrs2BmF352vrGrBpnhw6b3R7gHuEoK5yAgUTPIRY2OD2hun4HsN
q9MKmmeccZmNNidIEi6eJ3FXCDQVFj4vWm8sQ9BwXpCiGBai5045QqgYN46L
3jg3GIdEktHSiuTeWB+alIXJ5ChASaJLIeZIa1U+uJCi6PSJOug+AQ9iC9mV
w6+PBvRJ6Y31gEXExMn1RSo03ZaT0RpJOl+WLPbGT8w7ovHGkkNeu2HLrcrK
WyULDIaF1Bu3UInFyy/0eONS/5HxQR9dtky98v6CSx+4L4z1nBm9qvatcfcG
WRpfH5rpNSLdw1w+asmF2SfLnMevLjh+fUHJrTmHKx2hO5/vvDPOV/nO8hvm
WWU9J1x4eXjiiwUPzXhxhT4GMhARKDgu8qR43O8TGRSSOAaNDptCLB6jgOOb
qQyRu0KiqaAYzKEcJMwoEDSZOIJeoeFqFrV9n3akwuGH4wcpOJKAMLk6YBwS
SYZEK1KNVOSCJslhMuQClCR1twk5IlulCxdSFJ0uUYdPRaOJjOD5VbjdRwP6
lB2pyAMsyhATz1FfpELTQyqRjCScrxjQqzgCYmOyN5YPWVw7AKKaBbfpPOSW
6dzHn57p+vrZ1944//qwC298cH7IpPNDp50dNvvUsPk3B398f+Cgxj4DMr37
cr2H35pQlJpSXDGt+Pb0Q7enFt2x76mZuKN27A/8uytr3pxf1c9+s8cHVzu/
df2z2Q/R/ATEu9iDwr9IIB0QBRmFIy6bUeONQUfeJm48wTEI3YpcEIG7QqSp
8CHhJYpqY4IsggY82n571ixGfX/ojc0iasgu7CWhA8YhkmQItKIsGUYPmqSA
yRALUJKEqSHliGBVPriQvOh0iTrCLyayUvCfkh4N6FO26PIBi4iJ56gvMt5H
B6lENFJzvixZ3dgYCzvkXes+M/xtXkVdhyDSPKLirl6NvD6Aebk706VHabe+
Z3sMOTtwTGyM4+wHc4/1mXCh7wf3+g1o7NG33tS7euBcfszOmo921HwSqLHt
qP1oa631O/5dT/07S+venMcPmMr1+ZjtOepWlzdT1onph1Yp6J2IsitHQqBI
CJimqTB8TU4WSxZBkyFQVmS3Qaghjk2pv88NxtGQZHLRilSJ5fhWmYECGTLa
HJH4NnngQrmKjnBms6A8HQf6VICpsjvoJ5631HSRSk06X5rhBlyu5H4lJyzX
zZs3a2tr6TK9Ziv5857iTp1LXuh27MXuZ0Zak74fufMXebaKZyvLfTtPdLPU
vTag3tTndpeBNX2np99anh7hSb+3pv6dFXXDltWNW5X+YHna/FWmz6S61z+q
7TPmzmvvVHZ74/aAd+qT1x+O/VHYF3apowcqKqpWksobAyd84MAB7JAXLVq0
DmnHjh3Hjh27fv16TU0N9cbNUzqdPvXJxJIXuhwzD7m21c9Xqsfgz321sNLU
n+36+vkX36jt+VH9gC/Sg2Y1DJyRGT4/vf9UuqIqXVGZPnmhfukP/NBP6noN
514bUtWtf2X3/rUlJx5OFnhK0qGiakvJvbHw2m7tWuCHpfC4qKgIfFtWVgaD
eYqwaK5uFIdDz70c/WIal2NxXNXZWHkP86kXepR0ep1/dUS61wcNvT9uHPhp
5mip6sz6K+Xc3MVVvQbVvNqf796vZv33bW8+FRVVm0vujYHWr1//ww8/YM8M
HPLixYt/+umna9euUZpQS1RfU3P8g4/PL/ymvjZncFnPVl7oNzjw1EtHn+1e
12VgXY9hd7sPS2/KueVo7YHiqnfeT3fvy457iEPHSK3NbOFLfBuK2htio1Kz
88ilkolkUmdIuUOpwGzybMzrtFut9mAHq6aOqmZymTCnIhaLAQ+8Y8eOQ0g+
n8/lcuHw+MiRI1evXqVjFC1Rcs/esvVe/XPSt9ljvftv+OszR55+hX+lb6Zr
v/TEL9PVehy2uvKrdz6eVPFKz+rjBaEPWksSDqWV6CWVTkjcaZUB6cpFrZRU
M5AvGTYq7ZmDpJ5Q0YpCC9ksUvosWhTXjHQKzGYQ7X/n83qCsVbJUqtVU0dV
kxFDWJjhlkgkTp48iUckLl26VFRUJIXH4I/Lly+Dc6g3bp5A4Fp1/kLe0+pv
ps6M/3TVC68cfOqFms49a7v1TRfn3+SuPnWrcvRHN+3TW8PSQsVH3cKceV08
i67kPBb5FuotVaKUiedj3+QS3C7Z5BEmKqDpqU0JbtD0P6M9kkR7y7HJSCic
Y1PIJrCDcgkvKzbYhHXfwKmamuWNs1WpJ87dRGAOMRF5rltSTY+C4N4x6t3l
cjCv5MJ848rKyhs3blRUVNy5c+fWrVvALYPwGI9dbNmyJR6PF+KNmwJHolKr
ruL2nRPMxuHvFz39Yk3n16omTilw/KH+avLmuAlVp063tYVxAXhiNJvEDRMV
eBYr6FEZ8Eo6Pu4WGDG2MF5eK6PKmN0RJY9F8MbJsMtgEmfyc4zVaA7I3BkX
9ZhElqPEJmKjfosAuMFfcT6bZTXcpDIT9dqsLr9PoA458QbIcNYrOt9kNhuN
NhnTCO8+L0x+9TAsmizqDAiTUc1+HBNq8yUKLYM1BNQLU6BUoBg1O0hmgpYO
hHLhgzQgo2I2C+MWCtOBtumUeWMts4hAMdJWJQrsjeLcWoX9jEc0GJQ/rBer
sCJNrBEu6jVb3EF1WenUeLaaSOgkLTAKHgyIHQ85ikohuHRIajMsQlslyOlL
PCtZdiSRW46GekRq5MIRo0m79EnNvMpFK8IO+c6lA9P6P4m/n7vn3NGDm8xP
9p4y5QPwzy9/PltTFVs6+kn5rdUUKQ1KKxfJikpHwVlz9z3zQurFblzoUOFX
1V24xPp+TPNtGWwkEV8lFOf5pN9hwo+wGs8CIsN4guUQQwaFbQxixHCYKmOw
heIpEDTCrd4VPBYxNkardzHuAC1AU/gftF5PiOJEGga+UQCu5kriSCsbZmN/
ZXEFk0m4Ogx1GzG/JcjyfAwig1T783JBOEffEU3CKbvYuxrMrlgyAW2Bvk6b
r6zgEeL0Py0oRpF32YkkOhDOhd0XTqYUtoISMLvDIYTvAUErL3pjLbOIQDEi
VSU+DfwUcqmkesibizkwcQjYIF/dFpHWGucoq7w1TkYnEYBRuBihpyXYl20j
0ob1aJEdsJOcPmFVnbwqc7QcJfWI0Bggt8nkinN8Muo3aRaiKsBN+rSiTPxz
5EYvVlTdKr986VrFtfO7e4Ajfx67u+TEtZsV2z9W31pLkdKgtHKQrKhy6+RP
P+199oUbw0Y2FRRfn7pV35abfaAKFQYYObF7q8KzCOwTPgYfRBOEo8BF+uAq
dMTqk7c4OY8l60IRh8wH2rzDIBJapAtktFhGZBNFvfAX3+LwMElOlRSkJdjw
O1Dc0U6h6Fdc6ssz5MfQ6Gazt7Mn5LfT5kt9bbbLD9+OueAmI0RQjIe0Vo5I
B4K5kBY/yoR+jxjsJUA2k+D20AdqmUUEihGxKjm0EtlocQQYbeyEl+ApuRZq
8gOhrPLXeA7cEAlqhII9o8UT0Ot8J6ELsgCnGQYNyRbMlX4eb6xpOQTqEaEx
YERhSn6hIl0ZuEmfVsQjrIcP9RJBqFxXV1dTUdzFYNgev1NTU1NXfWY8oR2q
2VYyOJI+yYoqp+LFh4uee+nON+72NkStGILXCJ6M7I3FVo16SaCricA5ESaa
4NERm4IYKeexZF0oYgiY3F7wTFlVv+Bo6EBwlRGnUaLiJJiAA3WxIX1RlpSW
7cnD+MokTCDgIkbiYyj3xkZlKK7Nl+zaFAwUjSKLC8eNxhxgGXneJZF5R7mQ
7NJxFO0YLFaT2RUhMYsIFCNiVcKbJhiPA44G2P0q+KrKfRnF2NiZ9caksspf
4zlwQwSoEbIv4HEglFEgZ3CH7mv3wI4K9G+50xcOcmFtM9C2HAL1KEcjdwmj
KCRvLAM36dOK8O38svZVX3Wkm6HboQq0kTShHRLYVnKUli7JiiqnKpjTh57v
Vrf/QHsbohbyDwYvk+TZGOxaqUYqFDEG6sSZMTQ+w6ZElq/RzqTAA8LCfquC
xyJ/i5dyo9E0jbPC/s0C4xS00h85Hz4ejSJsAyOyhvS8MX42jTZPhAkhqIJ6
zgPynM5E9nakgRFFvmQSgiUHjtKRc84FlpHnPSsi7yivNwYKI+wCKhACs0h7
hFiVqXg0jm4tdfblZZ/1xsileEBFJoKIFO1mdcoqf40TcUOE2JUX7UPDCHBE
iE+WuJ3uEg30M4IhFCY3jhhzpW/2MHBEyExoBiRGt5Z6pG0MMPg3WL1Jno+h
JqqGtMjATfloRfB2RrsPZI5nk3BkRv/5IlGk5HAkXZIVVU5VxS6c6Dc4U17e
3oZolfKJ7BoQiQnemIRngeLibmmuF35JxMVcZvEA9htZHkulu1t2TgXqbBoD
2ukIXNQuAomcNiNKRNqKAg7zoY5dNinGTSAts7GgDYJqTC6fR9tF5bGHQe+J
5PGeNDBCyJf88mTEIdmD3p/gTrUWLKNgB8lKWMs7YrRsTJVJUAkQMoq/X1pm
kfYIoSoRIVM4FkyoBgPksCDWbxPemzpBstgbk8uqsBon4IYIfB4OzhAQyxC9
uKxEvylO7TS5ZBANz4rDXCScUcwnvC21uZxGgUkoK1tSy9FSj7SNIcX4ZNwm
LTJLwbzSpxVx8YCUNmwzeZ4vEkVKAUfSI1lR5VL1pfiVCZPb9n1cC4RgO4Xa
hhgyGsSQgldJ4LHATUaUL8hk4tURqS4giGgS/gPFrsT5PxzL5UlNmy+52FQS
SM0k0oJicrBompSdXNIyi7RHCFVZMJmHKxiSU0iNZwpFJ6loQgmb4ck9GmeM
+1CqYS5t+nzheVAaoLpK3Rh4PZZURk1R0i9wEj0p961JFCktSouOUjRBtVfK
bq/Js07kcRbHmDSM+tYT70MRhbApni/aNnehehgC0aNzdZHmdwtO9NWMtFBR
NUd1qVRN6W/ZS+TBabY4ebhwOZGI554lRfVoi6KtqFpLaaT2toKKioqKiiq/
WDQ0256vhvmE3+NrT4JOWxrAJ0tWbyjm8F1Wt2s2kZIRvy/UtB3POwzmqJn4
ICqqNhAH12cYna22GpOLObPzFkyt8XaYzc4mMBgdvkhBPp4NGx7OLHo0eUkt
oytFMqCFECd49YxiRTqVxeAuxe29HSac19xECkdrY46arWbig6ioWl9oBahB
hy2AVDjhJAFX69nguiWejUaY1gDPwPlUBkcwxSXRWn5jqJBHh7SGq20EN1dK
pVg2HjQZjIF4Cv2TU25+Lar5ECd8NUT5ZBSLeuQbST9MKRBDuSZd61zeUsxR
AYSfAi1pHj6IikpPfFykyhisbjQNHpKCbP6gFwdvTn9Me1HYaTKY0WpSkTZG
gP9oCCdaeI4kvLRNAUdTG5Z0wW3lhWA84rZY3BFdaopsjRgCOHijnJrBklEz
cGTeOOWxGs1OWCCEq7gsRgac72HyoIf0pPL/6J8+ZeFnIU45GTtxh8noQRyc
ZMgFoke0HpcP2kEOkjGfzboaOsA83lhVFBkuKN7LZMVLEshYnqhfKB90VUan
UlRgJTiH2eHLj/ERpcQcqXhWhUCK1IQfWd7VdZeDmNQK+CAqqpziE6EQfMBS
YRcm1QikIIMlGEsyPiuhj4zXpUY5NgTaqikkrOXSrtvSEk7U8JysuBiezG91
iStHNYZBHAEGYyIDgFvQpaag1WeOEIg+PQj6AE7TMFg0DBzoDEEwj7bANrqw
NyBfZXLGOT4VC4jLAfTQQ3rSeGOLpvCzSyNzMnYkGoYw2c8DygIiOyBjpGTR
k3jba11vrCkK4HBDYehFUmGTsDSYCIKAGAcE7eGSSbQERqdSlGAljA/Nh/FR
NhIJc6TlWRUAKVIQflR5V9YdiZjUivggKiqygE/xe9wuJ1xliUAucJGsH8Nd
ZEgfSYmAHcWxbAr2sg0W9MgQ4T8ywgkZnqMUG/E5ceCEm7naMBTiBlKZFHwq
gJvSp6ZkF/SZrM6IEJwoGSxaBg4iwFhBakaH7KjqqqhVi5HRRQ/piRAbqwtf
5kVzMnaSIVgmSZaxgFDMAsLUaCriwD9eJYu65ffGBBwQrICw3+tyOc2C5yF6
YxwTGh0evFo3X6XIUB4FYXwUUmGOsjyrgiFFWcKPKu+quiMQk1oPH0RFRRSO
ARy+UDTiM4ot1iS+R2MJ3lggTqAOGxC8OpED/iMnnBDhOQSlwha4Nj9OMAyN
OprdfhBr4GBMl5qiJTNoGCxaBg58oIw2+EyaA8JgipbcAmkDgk+QsTJ00EN6
Io1UqAo/60UzuRk7bBh2BZxWoy2YhHVhd1hwKRXojTVFgUihZoeXiUXswsqd
XFgejgl40KiSPU7CGakqRfLGBWF8FMpBaSscUiQj/Kjyrqq7XMSkVsEHUVER
hfi9MAZIht0GmTcO5/DGCnxlRoTnRFIk+I+CcEKE50hKRsVHLxU2w5goSTAM
RoA4eLZgT65LTdEQ1QgMFg0DB+Wd4fmQ0wSpGpALrL0KcXKM9iAT8aHhFTd8
AAnooWSJf5Hbn8cvk7yxqvClkQotY0eeXy8ao3CG2AyPJ2wI6WS9cUm+kQpZ
UaAKNQSSGPaOY0ISlodPRaOJjPALaxTBnrkqRQFWKgzjo8hjDmZmoZAiOeFH
nXdl3ZFG3loRH0RFRRAfD+B3DUaLDYY3Jg8rI5nIIwSskMMo9i6xYNALgjAS
/CejJJwQ4DmSpD0vDCIEhmAYNDeKBgiliFeHmgKfHbNiXyQSg0XFwMnmHZwM
h2HCKdJVbMyN+rQ2t9eRfeTVtBnG3d9g6F+iP3VB4421hS9BnLSMHbkQchn/
TuFK8XFC2cpiYwEGVdJf+xZPVRR83KmoADh0T8DycEwWSyR4UT2UjRysVCjG
R1anbpmDVfB2CoMUqQg/sryr645ITGpFfBAVFVm8CCbhm0FcUSSkhf9kCIQT
cpcNfJVSYXkKM6xJ1JQcDJY8GVdfxYlWojdc8ukN+uih1lAe5kwLpSwKeC/x
DyFTRCyPtgD1KiUHYkh+tRbjU6jxBTSEXPcvqO5aEx9ERUXVUgkztfCUKLuf
ggypqKio2kkQFp4ASlJPTEVFRUVFRUVF1X7KEm/4Et+GIkpuEQV3UPWG26g4
kkyk8PVkiWg0R58hFfI6rVarOyhNpWvDSmzTAqGiejzFFT9pMBQViE3IEm8q
nRCH09pvq5tkTCte22Kh3UWbDxfSEZrW2IQ5WmgSAgEHhNYNmTw+rz8Udhnx
4rvCKrFZBdt2BUJF1Y4qnP9TeIoyxEplaUlpoaSg7FxZ+S6orShdY/KQYZqS
kdYWaalOa4iHc4DVKybyXBKzkIhSDJoBjP9OMJF4ii+4Egst2CjEEnmECTCo
QGhsTPXIiEANygJhBBaQmv9DIKJgykrAa8czc8OxCJ7/aXYEOMJdlIgVrvTz
bjbs4fhE2GEWzoSPM8E8tTcOu8wmR1CEF3mNJqd8Jm7Ua7O6/F401dlo80YZ
P7bcGYghuwJi8iY3XhQgGUOgJynNJtgmZUSLrFGIQCLKivWBa/0+vGuoGW0x
TCgHTVllvXEqAtflwuxoyT9oQi+6yGQ2G402Jh+rJxV2aCPMPNWNlwabFQt8
ELbCgBdwAplMFi8cz5B5Yx3sUmEFi2J4oVg9wo60zkAO8g8J7qSGMmmbR96M
J0Juo/Ck0H2jqJooLTVIvhxMXJEk5/8QiSh4ITPwUYlUFLdPSGuJeISFe5q7
KBArWQcLwzDQjuMsRtfwJPPU3piNuEVgJlyTpeoj43UlNm8kGcPLSSCQJwLZ
x3AtG4eQQOC0sMskrOyW0ifRkxRm69lGQNbIpSERyYWvNfsi8WQU2mzxxQj3
0pQVcj4ejo+jBTJ4vZuW/IO/DbI8Hws4DTLyTy5WT8Rl1HIv81S3ANlQ+XA2
6DBCZBBkh0L+D1qaIXljXexSoQXLBeGqcUcU7VlAIv/o3kUDZdI2jzwZRyn4
4xxeV+6hbAqqJopEDVIvzpXxf8hEFHSmA4dVEqcCbU4qJKW9S5bfIj5rPMIU
+JQoX82F2pGKhAMuho2DHwcDXswrE6QW2LFryoIL5DSkVCzsdbscEAnkTsmM
IdOTlNiZ3LaRkDXKUleQiBSC1zrEC4I24fdFdS9tWSFHYbaY4KLt7FEl+Uex
sJ0Xakef1cOQKMR5qxuN2apzLUtKWlUnVqI+dqnggoU/viIvhUD+yXMXApRJ
1Tz0M46WQxqsCJlkoDh6qiYqBzXIKHumXKyC/0MmohBXkkrPC+Eucn6L+Kxh
aIyc7EAyjzBuDE0y2r1OAsoyQvAA2V8ZBgbJZm+Iifjtgv0Kb6yhJ8nM1rWN
hKzJSksiUtQJhPOI/iCAvLH2XqSygqgQ6GRMzhg+rCH/8DB4MwnzDLiIPKlc
rJ6sz1E0G73qzpBjYyKYQvLGutilQgsW/fjKvTGJ/KMHd1JCmbTNQz/jGNMd
YHBBgt4PXYdH1QQR4DzI4XiYFJeAqFi8bF/O/yESUYh8Y6mVEu4i57coRyqM
aKQUrq9geRLUiPQWjw3j0V0NOoDoASTvCv0zwm7wYRhTuTSxsYaeJDNb17Zc
fBskAolILsQ7cvixoVZ0JomhpC4rWAVGN5dJwiFpoyMuVIqS/INwZ0abJ8KE
UEcbcyT0WD2Q1Sn4Hz7ic7vRnlb61Q2vAr8iur+Mam9MQvfISqywghWWSQov
DkhG6t1FA2UiNI88GccQLdyqW8oZoPrNiQTnYf02YTMHp8uKvbGS/0Mgoqhi
BqH3LbZS0l1kiBUZxIaLByR8CwhBSVAj6eRKd7fs63g8YKgm6WTUaBoxrBWs
jQeEjFhsMM8wd1L6ZHpS1uyUnm1EZI0kEokoKzg0ajQLBB8TWnlNZCipyipr
JB9zoMwkSeQfNha0wXd/JpfPkw1ldVg9qP+OgJBocysSVEdV3UoUsKwuSCMV
2UrUoHtkNhRYsBkehxDSa01CHJvzLlook7Z55Mt4BjMMpUpRN0cqKn2R4Dwk
NoyC/9NkIgrxLmR+ixKMUxA7CFKX1VtFNN+uPMqa3QLgEpFfhA+gkQoWQZjy
MpTyQoTU5B9O+GcmBcM8+azFnKweNE7ShN0roqAy7MGCT1eoNbBLoJ3mSSH3
XdTl2Zwa5vNiqKioHltxUbd23sIjK9bVhi+AhK2acOfH7iv09ysRCRe+YC7B
UIIkFdVvVTAaeXxiEZ5ry8iK51KQeBRPPkYlRkVFRUVFRUXV6npMKCt8wu/x
tRdMqEVl2FqWP7QSaL+i5pMlqzcUc7I/OriSJX5fERx6z2twMuL3hegW0791
SZSVyhLnI4xbYcMG9VbFeYS2krdIL8BBOZjVuxUXfPOWkGqaajnHZPevkmR0
pZpeAs3UQ7uRKNgwZxRnZE30obbVFlChtJbnEmxBzW1+VI+NePguDM3eqUww
TLxZo4pwW2fNUt+2lxzmg1dtNCVaYvCcJ7RgNoM8qin34yDn0mjVIlINedWe
jngWrjJm2XjQBPdUTaF/cs0ogWaqyQa3VJWJUiYOPZm0/7ViQ+0WKx8dq/lU
KMLO3VkpnpoIafEj1W9EcYFzYjSLs0m52Ib+1g1oO8uozWT1+eAUSrRPvYa4
wie8diFAM7sjMV8WL8RAkENY3JjU5MGdL1mCX66ZYzA5BKcPUUXmgGxpFIHn
o4G6iFIxiKCL8CloP1A6OBdpj1QHmmUq88Zc2CPsy2myeUCXXMWl0RYImo/q
8HlsuEi8kaSqlGyeEH7WSYUjObeUBxSHM1Toc0/aeFpTAlzIbRUsD6vIQJit
BKzGoCJHBOaFQBxSVTfRYAIQiRNKyWgCTczkQXWXm1MUd5iMHgRIToZAYdoR
7IEP2kHyyZjPZl0NvVYeb6yyMzfnKihnCinpWE0kSinqQ1t0Ot5Y9dTAqdEO
n0/gIjmj+bBOVI+PkggBFIrzfNLvMGFvnN3qHZNzjPZIPMFyWuIKOmKwheIp
TK4B3slhNEAyDJziAFd4QUANOBqC7tePlodlE7wOF/3hNQJx2CAVW9ITeD4a
qEv2ZAWDKIKeBAXtRx/nAqIRszscAjdC6yN40RujzehNwTgL96yHu7eDvMu5
NAQEDV7CbHL44qlEAC69sMbwaSZnjOVBEGuGycQzxMKBzg0EZpzfBgccmvDQ
abyxtgRQXuyQ9ARZampYMf49cvgiyWTUiUBFPIE4pKluksEaIJKQ/TjHpxC4
Ca2X1OEU8X4rXp8oTMbzAFshUsMQTAKf9qTKp5G8scbO3JwrJVNIQcdqKlFK
Xh+aotONjRVPjdBTs7iCySRjE+Y66mGdqB4boYdUaEucOFKRbTAIQxHEj5mW
uIKOWH3yNw6sR8TgoAXU0hxguPbKAlqRPMFMJghX5PpAG3MYRBSMTBqeDwHq
IkjBICLQfvRxLqhvyOA2D+xIAt+EeF+iW5CSskQ5GZeGhKBBIxVOIdPwl84U
TsHF1NLCNHAv8DixOQoH+moQAxkdTXuLQ4iNVSXAQdSTwYQKAMZYJJ5PWLTa
JvwyKolDGW11kw1WApFQwClmn8NL8PQ5RXAttsGZZBkLCGQtILiNpiIOPDqk
9Wkk56a2MzfnSskUUtKxMk0lSilsUBZdnpGK7FODjUHLsQstLqrHRoi3I7Ql
nuyNxcdcS1xBR2x+hTd2i+0Kdeqlhg2Pmz2Mym8g/IXJ7QXO2KqO1rQ8n4wa
6iK7rZxBRKD96ONcpJE6zOC1WE1mmAUOlY3wjKDn1Iw7kqI3JiBo0EiFW8g0
DMmM4RREQ0iLZOHlZs/1HIVjhmulIVEo0KSZCqSRCmUJoMEc0GlHtjJMVDXX
GJaAixGtRt5YQxzKaKubYLAWiBRHlwsgH0yZ0OcUZVgQUhodTqvRFkzC8rQ7
LLhDUaA3VtuZl3MlawBZOlaTiVJZ+zVFl88bu2XeWEvzyFNcVI+LkJMxeJkk
z8ZgH041UqF4zLXEFXTEaGdSoHvPog2UOdi7dGCCJYwJLV74jLNRONwKAhLN
ex+4otmgZSOQgC0aqItMCgYRifaji3ORvzcJIx4H8sZ4/MSKOposcucQny7j
0hAQNKj/a/JHoXUMdAIg+oLUZVAQGOdhg3/GdAqH4fkQHCwwBtCQerLEv8jt
17DGVLVI8MaqEkA+1oyHTHk2xWlHKoyOKHxBlYJW2wIE4pC2urUGE4BIqEkY
7UEm4kOgIjf0YnqcIoiUR2MUzhCb4fG8ESE7WZ8mNtFsW5W1BpWdhXOuZHSs
phOlJOsJRUewXF5/sqeGyFbSLy6qx0Ypn/gyCcSEgjcGP99PCt7YrHjMNcQV
LuYSZ1lhj5oIOnFi4Jljoz6TeLrdh0IvVYKgwaKRuoDG3WiBLVqoi0xyBhGR
9qOHc1EifBMg+BZ/HVJ+sXBALx8v95VzabQFgryxUdyRwyTsN8EyjmwyPvw7
ols4XABeYAHPMePubzD0L9GfNKDxxqQS4EIu6W2RWcWzQd5YtBq4ZQ7tNqIh
Dqmrm2AwCYjExtxoKMcGekEigU2PUySMLFnQgBTsoRisPk6wUxZhPinGxk9q
3uJpmmVezpXYALJ0rKYTpUSRik5ruVzyp0bFuSqkuKgeJ3GQT1PwC3wNcUUN
SVHAgPJgbSII90MGuBCALXqp5WAQqVJs8qJjfJHqVnIujapAeIQdZeFUM9U1
WsxSXuZPK4snGZHJjlTwKQVkUk0cwspbiGogEidejN5qyebD5OQUtYrUdhbM
uZIWprcACkUuOt275m++bVpcVL91wU0TREAiVfsp4jS23bshYQYXnqCFAKFU
VFQdTwVHDlRtqjYGFbFJCCpCbxaoqKioqKioqH5DkugoHVh8iW9DEZqRVaC1
qVjIabda7e7mLRcvwKL2JB21CFPzEC3P8nbATVerb/pwYDutcpfWw3PxEZ83
1F7thqrVpQ9CIX9buQgSUMiDvRIdRfqj6dJLvzVU6RTTL8zIBNqBzu31eKNt
1PCbjN9h4bRei0e6IuI0a3c+KlAtwtQUannz65TA26ksBjctVjbLhwPbaZW7
tAgtpUzJSXemfqykD0IRv5VjeYB7guwW8jXZeZUi4KUwKcApOum3hrLbm0rW
6gnm3djqpFEFoKbJnB/kjQ0Gm08gJCDsXK7SzoNyahGmpmBwkFSn+tglrbSk
INmmpVk9HNhO1J3zLvmIQ/Iz3YTle80RnpBMY+PHRfogFOFbJZYnw/lsltVM
pT4dRQK8RL1wLj6QCchowrAdpwhksbpDvBqcIqVP5O2wXqvZFRCmtZodAc2i
VDUxRkNcIXljNiqaZFHOxWU94oxiC5zz7DVbXD6I30G7r5KxSDZ/ADNqjJ5w
1I+nGpudCjaGElDTdM6P4I0hRgN9k/XGmhJTQWm0/BmEqfEqkUEtIh0x7v7d
Fql+44Q6VWOXBDWNFET0xjlyoeFcZS1irEarsHwz6jHhjgamWvkFwJTdG+Hl
FQGasEFa+K9kCqkqlESp0uK5lO1WbSqBv5Thwl5x4rTZgzc9d/gDzlzPAtWj
JX0QivitAsuT9WZ6dBQJ8MKzKfg2nU14ESohBLecT4RC8OxU2CUsK1CAU5S7
uqt5OywmrrmCsQTj1WyHpyHGEIgrBG+MoTpxApEow8K8GwOxJMg7Rs0Y7b54
MsXpYJEMtnAiiRZEGMyuYDIRtmj2UJYDaprO+YFBkTvCINARfK5Fb0wqMSXK
ScufwZgaJTKoRaSjZGnRHkb185FtMzLsUrbWmkQKInvjXLlQYp1kLV+2nk5a
l4erz+SIJJLRgBP86YtxCYRTCSZYLsU4pYX/GqaQokK1lCoSnkvdbpWmavhL
uEkYPOE4x7GJOHiQhB/lHM8C1aMmfRCK7NsslkfmzXToKKpBAMzt8UbFVdap
mN/jdjnhcl3UhOTgFDF9nsDb4VA8ICCGtN1kDTGGRFwheGMOLU82WhwBtRsR
74LjclgyjmQ2ZSIWyRhEJqPhQWEdnLSoKpuqHFDTZM4P6qKCSBc99bZADPgi
6I1zlJgS5aTmzxCQQaR0WkY6ypZ5FrskU5NIQTljY00utFgndbWqVjej6hPz
mECUCZiYlLJ8pELFFJJXqJZSRcRzZUU2Vclfwk3C6pP9LOs+C1SPnPRBKLLI
2aT1xrp0FLk3ToRgmOESu9s4wnT4QtGIzyg0ITk4RfLGBN4OK4yVZQFBSm+s
JsaQiCvkcWMQ7XgcML6y+5V+RfXYistg82KRZAQDCTiQlRxQ03TOTzZBBLcx
Wc1GVzhniclQTgT+DAEZREqnZaQjmTeWsEuKDDWBFJRz3FiTCy3WSVmtRjE2
dsq8sZRHzDsqB+G6SUxZ8sZappC8QrWUKiKeKyuCqVr+EmoSVr+mGeR4Fqge
OemDUKRv5Vge8cnSp6NIf2AwmhURcvDiT9gXQzDDZNgtAmHk4JTsSAWJtyPz
bIQWqAUZaYkrBG8sEomgk5ECIbGISF1aqDxYJH1vLAPUNIPzI08Q9mQNQt+E
WGLysiXwZ7TIoBzpFEo6qkzEShOqiTjZMpdhlxQ5KpwUlGOkgpALLdZJdkME
cwMNBYNHBO4KDPUdfjgslELtNpDgGUi2soET2Rg8E/2ukahW8grVUKqIeC55
c1CbSuAv4SZh9MHuG59MwJEK3WeB6lGTPghF+laO5clUurvh2FWPjiL9EZEA
LkgWN9xVQXGdCb5AkYFTxPQzRN4OdJh6LVBDjNEQV7LpZ62V3tUZLMGEMsbL
ERtn8pB/5Cez2pEKOaCm6ZwfZYKJoFEcKSISiuRQGi1/hoAMypFOgaSjkhkG
w+eqeYPZMldgl2QqnBQka5ZZkXOh5VzJytCPX/kZzE5QzjJvbBaTsePXqdmi
MFnEXgaBKSSvUAKlioDnUkhtKom/JHtvjs7J9yxQPb4icU2aTkcRriMBWXKA
U3KgbnRNVfNVCiCuFEyVUV3WEpRL3gXJuTg/+ZLVXKRBOcnuzOMAPZVS36h5
pKPkHtuTeWZxK7BLrST9XJBvx6nyIo5U8OorEAZKmS65CcvT01Cq8uK5VKaq
+UuyVHUSoaKiosKKBXwlbThdvC3FhY10ZgIVFRVVBxDXnP4RFRUVFRUVFVUh
ak+qScvYLB2Rx/JwwDhUVFTtL32CUHPUZKoJWlGVXZvMojVmzbx3i9gsupa3
fkEVpIcDxqGiomofKXBA+gShZiTYZKoJXt+Kl4hmkEc15fY/+vwZPHG3udEt
YYawTK1RUE2XDrKGiorqUZcCByQRhDCZxy9s0Wnzhhk/nl1pDuBtN3PCWFR8
ITLVRAtUkcS4hbnCDrQPqcwbc2GPXZhoafPEuYyaP6MxCU3cdfg8Nmy5N5Ik
poOyQ2ATSaucIh6rwexSrFbIFlQm6hfQLphQJJf6KzUrKemCC+iE9YkRt8UC
T9OSggjIGioqqsdPChxQdokTJvMYPZFEDM9yN7tiybjHIqBddGAsSr4QiWqi
BarIFHGZzO5wCNFw4LRP0RujVUimYJzluTj80gruLufPEEzC669NDl88lQjA
ZSrWGE9Mh8wmAt7YFWXjkIaDSEeKUpMKCkJ40PlcUr3NkOYrDSsJ8h9wbI9W
IrsZVksKIiJrqKioHkPJcUByb2w02EMoNmPDRpGZI2x0ng/GIuMLEagmWqCK
/GpEqWWwKwNXJkGsDL2xxPhCKcEhCEuUk/FnSCahkQqn4CIhQQvcnZQOm4NN
BMy1WuBq34RmSCJbULgvYHR4gkn1WYSv1KwkxPUKpDIp6HKBzVpSEJ8LWUNF
RfW4SY4Dknlj4vp3AeitD2NR8IUIVBMtUEV+tcQMx3QLi9VkRvQqxFwRHBFa
8g+x3ln+DMkkNFLhFvn4ARSZk9Jhc5J2zDbo4x2BmLrQFJwEjgl40AiEXbNP
k+IrEisJcuDNbr/LLETRGlIQR0TWUFFRPYaS44AK9Mb6MBYFX4iUjgaoIr9a
voNDGC37N2MsAMJXIbABi9y5j1fwZwgmIe9n8kcRjwKCDyCniJROTjaRK8ql
EH3OEVBR3SSYUioahfdHjl25hkvzFYmVlEmi9EU+A4EURELWwB3i3E53iTZo
p6KieoQlwwFlYSxqGgmOHBnJVerBWOR8ITLVRANUyYpR7KeTcBilkdKU356l
2DDCNhcy/ozGJOSNJY6MyY/fP5LS0WcTYT6MW777Rha1xGRhQwIYTTpH/RWR
lQSiejRoLb3N1JCCSMiaShRmLyp56HPsqKio2lg5aD35rtKBseRNUANUKUQk
XoqCP6MyCXFkEO8lfzrNYRNlL8yRE/VXRNCMRhpSEAFZQ0VFRUVFRUVFRUVF
RUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVF
RUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVF
RUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVFRUVF
RUVFRUVFRUVFRUVFRUVFRUVFRfVbU72oug4pybz2LicqKqqHIZ7nI5HIihUr
Jk2aNGbMmNGjR78v6j0k1T8lPZzjo0aNGj1m9Lhx4+x2+8qVK4GpwOCW57q6
mv9p09mJo4M9n/uh0+/XPf97bwf8AMOAeRNH/wxMBQa3PNdUVFQdU+l0+tix
Y59//vnMmTMPHz4MYrD//M///EeH1N///ndgXklJydy5cydPngz+AMY3L9cg
5tyx9VzfrpuHD9+zfN35fcfunLrScD71oKN9YjceMFcagHnAyHeGB/t23QTM
Bsa3bhugoqJqd4HnetOmTSAeTqVS//znP/+/Dq9/IgHPfOvWrQkTJvh8vma4
purq2vkzi/v1C/yw6/qZW7+eq/j7udvCJ0b6nLtNPqFNjwtHKoT/AjtLb/66
IXC9T98d874qBlloi/ZARUXVLgJx5ubNm6dNm8Zx3P/+3//7v/7rv/7xj//q
0Po///V/kIC1IICvqKj44osvQBaaNKZaU1OzYG7x2+/v33qslrn+C3P9V/i5
AT7/ydz4u+yPDvLBtv164vqvJ5K/llx78MPR6sHv7ps/pxhkpO3aBhUV1UMT
6OMfPXoUeLPS0tJ79+79/e9//387qoDvlf8TmApc8a+//ppOZ86ePTt9+nSQ
kQKHLHie376tdMBbe1cfrN578d7Ra78cvfar/HMEfVR/yL96OMePyI7jrw5f
/eVw+S/FiQeBc41L91W9Pvjn7f7SVhk8p6Kial9VVlbOmDHj559/vnHjRmNj
469I/6kUOIA+hYgPzBoxYpaflx+ZOmJW4Ephl+cUNkO0J6sHDx6AkPjq1at7
9+6dM2cOyE7eLIPzb96sGPpOYPy3Zasi6R1n7x648uDAlV8Olv1yKCF9fj2Y
gEfgcfQV/Fz5FX8OwA88Pn3UiF6j1m+XHfcun9XljaWb4+Tzc6WT83gCf34V
7LnyCza1KP7gx9LGxQd565L4m8N2gOzQuRZUVI+0wCN86NChpUuXxmIx4I1B
iHX//n3g335pvmpXvmEAmhq4mj3ylOGpBSdbkCZZwM77D+6DeL66uvratWvn
z59fuXJlcXFxXr9UW1u7ZdPxPtbi2XtqFh+sX3OsIXjx/r74g6LLvxA+cfTR
HkGf9d+MBZl9Z90N4XhJ+N8Nhlfmn8l1fouOo8+++C97Lz3YfeH+iiPpeftr
p+y4AzKyedNxkKmH02aoqKjaQnfu3AEebMeOHWVlZcAbg8ASD0Leu3v3nkJ3
gRplUvxDcbxqjdmAZD5chY9VLe9u6P7NsRzn50pHcwRJZVM6nQZZqKioAMaD
LIAIf/Xq1eCITpaBrwbnf/blnpELL07dyc3ewy8I1S8/kt5c2rgzdn/3BeDo
Huy68GDn+Qfbz93fdvb+1ug98PkRfM6gD/qn9PkxWjYYZvaLFfCfGfsI+Pcq
vfObdnzb2XvAjEBMMAlYuOPcXd+pxiXF6Tn7+Om7a6YEOJCRT6cEQaZoeExF
9egKOLGFCxceO3YMxJa3bt26ffs2cMhVVVXAoXHVXE1NNfgf/A8Ux0kfTva3
+vj15W8bBH3kY+Hx6990NXRdcAifc7l4w1vS98t/TuVMh3SQA2aAnwtozR0O
2HgHmFrJssBsYDzIAsMwixcvBpnSyTJwWYlEYpB1zyff3Zy2u3bmHn7Ovvp5
RfULQmnXwfSS4oal4YalxQ3gj8XFmcXwv/CzRDii/oCDcxbPAHkxzSt3bd0A
/hi85pZw/u6TfbvijBrfcpfj87/eFurV1YiPdvriZN70pW+BVcAeYOGiA+n5
ofT8onpgNjB+2q7aT7w3QXZApqg3pqJ6dAXiyRUrVly8eBF4MODTBD8ser1m
6eaSbob+S7atGAUdzqw9ZTU1FeBItwVh8F0FsxYc7PbZWubixfDmWfBvdLwQ
1SJJ/0Q/D8gjI58MjL958+alS5dAbAwypZPlurq68+fP9x9XbN9WNXMP8MPp
hQcavj4IHS/0w4fBp3HpkbvLhE+D/AO+XXa4QXVw2ZFbbz4HXe5/gP+8sckl
HIz3Bv/svXzaznLb52PAt7Zd8PhEK3DFYyb5r89YG5r43fXC0r8LTYIf8EfD
4nCD61DDooOZ+QegT561l5+y7U7/D4tBpuj0YyqqR1Sgmw/c18aNG4H7Av1c
4NOAf8N+j2++UkuB7116kk/t6wb98egzPLsOHFl4GHx3eGE3dETQgTnwnyfZ
Zt6plhf8M3bLwCGD+HDTpk0gUzozK4DLikajQz8rmbGzZmEoDZ3w4Qb3kcZv
j95dcfTuqpJ78HPsnufY/VUl9z0l8L/Sx6M5gj/LfliHot3unwaFI0v///bO
9KmpM4zi+Tvaf6Ad/dTlmzrTL52xrdOZTtXWulSYytBBtAbFgq1YFFAEkV1l
CZsLWBS1bCqEkAiEEEhgWJrIvgUCSNhiQdNz7w0BkQKCCtjzm2fu3Pfhzptz
Zsjhvbk3l8QIjD8PUJ2+3hSQmPaeTPZ1bDv6Xj8Ih+2LrAmfb57/ml+SJGmL
KHoCqWFCRA8G5w0G5lr9snq+OVQMU0xjQtYpiCysihMTE7Fta2tDpkk5LD0M
wbpMWsM2yTYFFQlRn3kY0bP15KWg7VKnNWorxlGt04eqwrZjXNC6wGzz4NIm
PVBCiOXeXiyV29vbDQZDSkoK7CycxmVlZfuO5f96oyu0YDBcTOCYElts6Uhc
qS0OW83oJc1oXOmosC/U6KwamVWz+z27PpK971nk6kemx8teYONeRS/6MbkV
2zY7OzsiDEudXy1IildjHzpHY0ts0cIfi2HEMtbz/pldbr6FMMU0JmSdgsgy
Go0XLlzQaDTS9Tu8naUcGxoaGhwclC6fDYq4duYdzup3hCONg4vFUbfiR2cY
fRGuxLgwYJNM5mmYPrg4GMMd6u5555k7/+wreq6m5AKyEchYHmN9ePHiRZha
OI21Wq2XX5o8qRlRjFhD1l15NJZYNpZUNqaoGE+SShyiEmfVvE2xb9n7seyD
XzSuTowiFK53KSzzHh+bq9+1Rfhc43flIvMLQ0GMU5VC3Ef/smYsToxlZPJR
RYu3XzpMMY0JWb80NjaGhIQolUpEmfQNAunuheHl0xWxWbbhrGp6pNoppvGX
YqdNJZy//xyb32ax1KkShKtZ8jvLeA2bzea6rQKCB8Rrc1jbq9Vq2IGpBSzj
SMT1b6eij8T/jTRDrCHlUisn0nQT6VUTGXpnpeuclVY5U8JQqso5/f79n8g+
9Hk00yxv2ib4dj96vfmKquf8tZKgwqG0yqETgYoTWc3JFT1H92+Uyb4/q15k
fklDRpW4hSq9UxIEQ3bCI2TyyLHLpt//iIEpXsUjZP3S0tKSmpqanZ2NBMN7
GeEm3Wy8gm9pWCK3yL6K17rGXUphlfhdpLOjzzztOnvf4pPcOryClxobk+46
RizDi9lsvnfvHuzA1AKWYdNkMiUnJx+PLD2fa1Ug8ars16rtN4xPs8S6Ob0z
b2VO14v9gZ8+lW3wLX+hr67a+dnMRxUH/hzAYYe+nensjjS+NM/c+V8+AHWj
5un1GnuG3o5MDs+z+kerYQemmMaErF+wHtZoNH5+fgaDQfrqx/j4+NNpXM+C
eM2MDYtfVRhb+Ux2ux2CEcjwUl9f7+/vDzuLfk0Yq+ji4uIjx4PDbnen6+w3
ayez6ydzGqZcdacR28nXUlm6voyKoexZneyaoYyKvqy6Jc4g6nGpapQUTt6q
n7xZ9881vT0ip0d+PBh2YOqt/MoQQt4IVqv18ePHCQkJOMFvbm7GIhMR9+zZ
s9V+QttSgdTJyUmskDs7O8+dOwcjsLPooyr6+voaGhpwsPxkbJJqGPmWa3bk
NzsKW+YWmgWoFqGc+9LwbfXzxa1Lj/QjNPPMzyE7VT3sczIWRmCHHxoTst7B
u7i6uvrMmTMIZKwqsRhe7Yh9NRDIcBEaGgoLMLLEUOru7i4vL4dleUDULaNd
2TVV0uMo7XWUWsStuKMWq3R1a7akXoeqx1EilrJz6rZxwudUFCzACOy84V8T
QsjbAO9lnOAHBgZ6eXlptVoEMiJujT/lGPIgcmpqSq/Xe3t7QzwsLP3Zkv39
/e3t7UqlEhl+4KBP8v26soGpqpHnVTZH5bCj0ubQ2Zzb1a0qsQRJqCfSzvMy
65Tifp3HQZ+goCBYgBF+YkzIuwFO7RHIOp0uOjraw8MD4aZQKJqamux2+2qH
7vxAmMlkSklJgVQIhmyIf9X1oRTIyPCYmBj8GfI8LA9JuHrXaNI+maidcKzB
0g5N3DWYziZchVQIhmzp1kRGMSHvGBaLBQn84MGDqKgouVzu5ua2Z8+e3WsS
CIM8iIRUCIbs5T3gFzmGDK+trc3Ly8NUvr6+np6e7u7u+9ckEAZ5EAmpEAzZ
EM8oJuSdRFokm81mo9GoVqsLCgpyc3P/WmNAEoRBHkRCKgQv+5/iSfT19WGF
2dDQoNVqHz58iJfIycm5vcaAJAgrKiqCSEiFYF62I+T/APINq03pyTxrEAiD
vBWG8BywyJQsd3R0tK1JIEwyzvUwIYQQQgghhBBCCCGEEEIIIYQQQgghhBBC
CCGEEEIIIYQQQgghhBBCCCGEEEIIIYQQQgghhBBCCCGEkDn8C7cLbdw=
    "], {{0, 234}, {
    474, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{336.66666666666583`, Automatic},
  ImageSizeRaw->{474, 234},
  PlotRange->{{0, 474}, {0, 234}}]], "Input",
 TextAlignment->Center,
 TextJustification->0.]], "Text",
 CellChangeTimes->{3.475846636570622*^9},
 TextAlignment->Center,
 TextJustification->0.],

Cell[TextData[{
 "Click yes. This will create a file named ",
 StyleBox["batch.m",
  FontFamily->"Arial"],
 "."
}], "Text",
 CellChangeTimes->{{3.4758460314143887`*^9, 3.4758460324274893`*^9}, 
   3.475846473984353*^9, {3.475846699698764*^9, 3.475846723707308*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "opts", ",", "datestring", ",", "filename1", ",", "filename2", ",", 
     "filename3", ",", "tmp1", ",", "tmp2", ",", "current"}], "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"make", " ", "some", " ", "plot", " ", "options"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"opts", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"AspectRatio", "\[Rule]", 
       RowBox[{"1", "/", "GoldenRatio"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
      RowBox[{"FrameTicksStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", 
         RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Helvetica\>\""}], ",", 
         "10", ",", "Plain"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"GridLines", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"None", ",", "Automatic"}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"GridLinesStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{
         RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", 
         RowBox[{"AbsoluteThickness", "[", "0.5", "]"}], ",", "Dashed"}], 
        "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"ImageSize", "\[Rule]", "500"}], ",", "\[IndentingNewLine]", 
      RowBox[{"ImagePadding", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"50", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"20", ",", "5"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<CBOE Volatility Index\[RegisteredTrademark]\>\"", ",", 
         RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Helvetica\>\""}], ",", 
         "14", ",", "Bold"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRangePadding", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Scaled", "[", "0.02", "]"}], ",", 
           RowBox[{"Scaled", "[", "0.02", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "5"}], "}"}]}], "}"}]}]}], "\[IndentingNewLine]", 
     "}"}]}], ";"}], "\n", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "create", " ", "a", " ", "string", " ", "for", " ", "todays", " ", 
    "date"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"datestring", "=", 
    RowBox[{"DateString", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<Year\>\"", ",", "\"\<Month\>\"", ",", "\"\<Day\>\""}], 
      "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "insert", " ", "the", " ", "path", " ", "to", " ", "the", " ", "directory",
     " ", "you", " ", "want", " ", "the", " ", "data", " ", "saved", " ", 
    "to"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename1", "=", 
   RowBox[{"\"\<\!\(\*
StyleBox[\"/\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"pathToData\",
FontColor->RGBColor[1, 0, 0]]\)/VIX\>\"", "<>", "datestring", "<>", 
    "\"\<.wdx\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filename2", "=", 
   RowBox[{"\"\<\!\(\*
StyleBox[\"/\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"pathToData\",
FontColor->RGBColor[1, 0, 0]]\)/VIX\>\"", "<>", "datestring", "<>", 
    "\"\<.xls\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"filename3", "=", 
    RowBox[{"\"\<\!\(\*
StyleBox[\"/\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"pathToData\",
FontColor->RGBColor[1, 0, 0]]\)/VIX\>\"", "<>", "datestring", "<>", 
     "\"\<.png\>\""}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  
  RowBox[{"(*", " ", 
   RowBox[{"import", " ", "the", " ", "data"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tmp1", "=", 
    RowBox[{"Import", "[", 
     RowBox[{
     "\"\<http://www.cboe.com/publish/ScheduledTask/MktData/datahouse/\
vixcurrent.csv\>\"", ",", "\"\<Data\>\""}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "convert", " ", "string", " ", "dates", " ", "to", " ", "Mathematica", " ",
     "DateLists"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"current", "=", 
    RowBox[{"Apply", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"DateList", "[", 
          RowBox[{"{", 
           RowBox[{"#1", ",", 
            RowBox[{"{", 
             RowBox[{
             "\"\<Month\>\"", ",", "\"\</\>\"", ",", "\"\<Day\>\"", ",", 
              "\"\</\>\"", ",", "\"\<Year\>\""}], "}"}]}], "}"}], "]"}], ",", 
         "##2"}], "}"}], "&"}], ",", 
      RowBox[{"Rest", "[", "tmp1", "]"}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", "\n", 
  
  RowBox[{"(*", " ", 
   RowBox[{"export", " ", "the", " ", "data"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"filename1", ",", "current"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{"filename2", ",", "current"}], "]"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"plot", " ", "the", " ", "data"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tmp2", "=", 
    RowBox[{"DateListPlot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"current", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "5"}], "}"}]}], "\[RightDoubleBracket]"}], 
       "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"-", "500"}], ";;", 
        RowBox[{"-", "1"}]}], "\[RightDoubleBracket]"}], ",", "opts"}], 
     "]"}]}], ";"}], "\n", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"save", " ", "the", " ", "plot"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{"filename3", ",", "tmp2"}], "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "send", " ", "yourself", " ", "an", " ", "email", " ", "confirming", " ", 
    "the", " ", "plot", " ", "of", " ", "the", " ", "data", " ", "is", " ", 
    "okay"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SendMail", "[", 
   RowBox[{
    RowBox[{"\"\<From\>\"", "\[Rule]", "\"\<\!\(\*
StyleBox[\"your\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"@\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"emailAddress\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"com\",
FontColor->RGBColor[1, 0, 0]]\)\>\""}], ",", 
    RowBox[{"\"\<To\>\"", "\[Rule]", " ", "\"\<everyone@gmail.com\>\""}], ",",
     " ", 
    RowBox[{
    "\"\<Subject\>\"", "\[Rule]", " ", "\"\<Your daily VIX chart\>\""}], ",", 
    " ", 
    RowBox[{
    "\"\<Body\>\"", " ", "\[Rule]", " ", 
     "\"\<Here is your daily VIX chart\>\""}], ",", 
    RowBox[{"\"\<Password\>\"", "\[Rule]", "\"\<\!\(\*
StyleBox[\"yourPassword\",
FontColor->RGBColor[1, 0, 0]]\)\>\""}], ",", 
    RowBox[{"\"\<EncryptionProtocol\>\"", "\[Rule]", "\"\<SSL\>\""}], ",", 
    " ", 
    RowBox[{"\"\<PortNumber\>\"", "\[Rule]", "465"}], ",", 
    RowBox[{"\"\<Server\>\"", "\[Rule]", " ", "\"\<\!\(\*
StyleBox[\"smtp\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"yourMailserver\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\".\",
FontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"net\",
FontColor->RGBColor[1, 0, 0]]\)\>\""}], ",", 
    RowBox[{"\"\<Attachments\>\"", "\[Rule]", "filename3"}]}], " ", "]"}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.474818499641177*^9, 3.474818543584859*^9}, {
   3.474818580396072*^9, 3.474818627675934*^9}, {3.474818661948094*^9, 
   3.47481889372392*^9}, {3.474819084170466*^9, 3.474819158135479*^9}, {
   3.474819198096957*^9, 3.474819200336281*^9}, 3.474819288776684*^9, {
   3.474819351752145*^9, 3.474819358094472*^9}, {3.474819498403329*^9, 
   3.474819501691181*^9}, {3.474820062836617*^9, 3.4748200780964823`*^9}, 
   3.474820118023497*^9, {3.4748202365537024`*^9, 3.474820241829527*^9}, {
   3.4758463358967237`*^9, 3.475846338287922*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Scheduling on Mac OS X", "Section"],

Cell[CellGroupData[{

Cell["AppleScript", "Subsection",
 CellChangeTimes->{{3.475848699810767*^9, 3.475848702274445*^9}}],

Cell[TextData[{
 "On Mac OS X you can run ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " from the Terminal. For example to run batch.m, set the correct file path \
and run the next line in the Terminal.\n\n\
/Applications/Mathematica.app/Contents/MacOS/MathKernel -run \"<<",
 StyleBox["/pathToYourFile",
  FontColor->RGBColor[1, 0, 0]],
 "/batch.m\"\n\nYou can also make an AppleScript to run this \n\n",
 StyleBox["do shell script",
  FontWeight->"Bold"],
 " \"/Applications/Mathematica.app/Contents/MacOS/MathKernel -run \"<<",
 StyleBox["/pathToYourFile",
  FontColor->RGBColor[1, 0, 0]],
 "/batch.m\"\"\n\nUsing AppleScripts allows you to combine other tasks into \
your batch scheduling. If this AppleScript is saved as an application then \
you can download and process data by double clicking on the application."
}], "Text",
 CellChangeTimes->{{3.475848401070705*^9, 3.475848401859556*^9}, {
   3.475848446937532*^9, 3.475848469639928*^9}, {3.4758485655097933`*^9, 
   3.47584861481663*^9}, {3.475848693469243*^9, 3.475848694501493*^9}, 
   3.475848761390517*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["iCal scheduling", "Subsection",
 CellChangeTimes->{{3.475848765957139*^9, 3.475848770020019*^9}}],

Cell[TextData[{
 "Ideally you may want to run this script remotely at a fixed or recurring \
time and monitor the result by viewing the plot that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " emails you. AppleScripts can be scheduled to run from within iCal.\n\n# \
Open iCal and schedule a new event or click on a current event.\n# Select Add \
Alarm.\n# Select Run Script, and then choose your saved script from the \
window."
}], "Text",
 CellChangeTimes->{{3.475848401070705*^9, 3.475848401859556*^9}, {
  3.475848446937532*^9, 3.475848469639928*^9}, {3.4758485655097933`*^9, 
  3.47584861481663*^9}, {3.475848693469243*^9, 3.475848694501493*^9}, {
  3.475848761390517*^9, 3.4758487810603743`*^9}}],

Cell[TextData[Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsfQecVcX59mLDXtLUWJFuoWNJ/BtTjCZREwUssRuTWEHpVUSahd7r0jvS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    "], {{0, 425}, {281, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{165.6666666666663, Automatic},
  ImageSizeRaw->{281, 425},
  PlotRange->{{0, 281}, {0, 425}}]], "Input"]], "Text",
 CellChangeTimes->{{3.474827972263653*^9, 3.474827974418281*^9}},
 TextAlignment->Center,
 TextJustification->0.]
}, Open  ]],

Cell[CellGroupData[{

Cell["launchd", "Subsection",
 CellChangeTimes->{{3.475848811820794*^9, 3.475848814900757*^9}}],

Cell[TextData[{
 "More flexibility can be obtained by scheduling using ",
 StyleBox[ButtonBox["launchd",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://en.wikipedia.org/wiki/Launchd"], None}],
  FontWeight->"Bold"],
 ". Documentation about ",
 StyleBox["launchd",
  FontWeight->"Bold"],
 " can be found here: ",
 ButtonBox["http://developer.apple.com/mac/library/documentation/Darwin/\
Reference/ManPages/man5/launchd.plist.5.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://developer.apple.com/mac/library/documentation/Darwin/\
Reference/ManPages/man5/launchd.plist.5.html"], None},
  ButtonNote->
   "http://developer.apple.com/mac/library/documentation/Darwin/Reference/\
ManPages/man5/launchd.plist.5.html"],
 " and here: ",
 ButtonBox["http://developer.apple.com/macosx/launchd.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://developer.apple.com/macosx/launchd.html"], None},
  ButtonNote->"http://developer.apple.com/macosx/launchd.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.474828316175076*^9, 3.474828349653767*^9}, {
  3.474828383936419*^9, 3.4748284637548857`*^9}}],

Cell[TextData[{
 "An application called Lingon provides a GUI for scheduling tasks using ",
 StyleBox["launchd",
  FontWeight->"Bold"],
 ".\n\n",
 ButtonBox["http://www.apple.com/downloads/macosx/system_disk_utilities/\
lingon.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.apple.com/downloads/macosx/system_disk_utilities/lingon.\
html"], None},
  ButtonNote->
   "http://www.apple.com/downloads/macosx/system_disk_utilities/lingon.html"],\

 "\n\nThe process of scheduling the VIX script to run at regular intervals \
involves creating a property list that resides in ~/Library/LaunchAgents/. \
For example: ~/Library/LaunchAgents/VIX.plist. Below is an example of the \
plist made via the Lingon GUI. At 8:15am everyday the script is run and I \
receive an email which contains the plot of the VIX data."
}], "Text",
 CellChangeTimes->{
  3.474826831083384*^9, {3.474827276703755*^9, 3.4748272872964897`*^9}, {
   3.4748274379407253`*^9, 3.474827438387424*^9}, 3.474828407846987*^9, {
   3.474828476954954*^9, 3.47482855025248*^9}, {3.474828690216107*^9, 
   3.474828777719431*^9}, {3.475848946512179*^9, 3.475849033594051*^9}}],

Cell["\<\
<?xml version=\"1.0\" encoding=\"UTF-8\"?>
<!DOCTYPE plist PUBLIC \"-//Apple//DTD PLIST 1.0//EN\" \
\"http://www.apple.com/DTDs/PropertyList-1.0.dtd\">
<plist version=\"1.0\">
<dict>
\t<key>Label</key>
\t<string>VIX</string>
\t<key>OnDemand</key>
\t<true/>
\t<key>ProgramArguments</key>
\t<array>
\t\t<string>osascript</string>
\t\t<string>/Users/mhoneychurch/Desktop/Vix.scpt</string>
\t</array>
\t<key>RunAtLoad</key>
\t<false/>
\t<key>StartCalendarInterval</key>
\t<dict>
\t\t<key>Hour</key>
\t\t<integer>8</integer>
\t\t<key>Minute</key>
\t\t<integer>15</integer>
\t\t<key>Weekday</key>
\t\t<integer>1</integer>
\t</dict>
\t<key>StartInterval</key>
\t<integer>86400</integer>
</dict>
</plist>\
\>", "Text",
 CellChangeTimes->{3.474825752417789*^9, 3.475849045335249*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{1108, 891},
WindowMargins->{{42, Automatic}, {Automatic, 0}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (September 30, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 116, 1, 95, "Title"],
Cell[CellGroupData[{
Cell[708, 27, 97, 1, 83, "Section"],
Cell[808, 30, 926, 20, 107, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1771, 55, 99, 1, 83, "Section"],
Cell[1873, 58, 1232, 23, 89, "Text"],
Cell[3108, 83, 35741, 593, 225, "Text"],
Cell[38852, 678, 265, 7, 35, "Text"],
Cell[39120, 687, 8678, 227, 889, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[47835, 919, 41, 0, 83, "Section"],
Cell[CellGroupData[{
Cell[47901, 923, 99, 1, 42, "Subsection"],
Cell[48003, 926, 1080, 22, 201, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49120, 953, 103, 1, 42, "Subsection"],
Cell[49226, 956, 711, 13, 126, "Text"],
Cell[49940, 971, 113376, 1864, 330, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[163353, 2840, 95, 1, 42, "Subsection"],
Cell[163451, 2843, 1124, 29, 70, "Text"],
Cell[164578, 2874, 1153, 24, 145, "Text"],
Cell[165734, 2900, 784, 31, 539, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
